@@ -28,6 +28,7 @@
 #include "encoder_gzip.h"
 #include "plugin_loader.h"
 
+
 /* Plug-in initialization
  */
 PLUGIN_INFO_ENCODER_EASIEST_INIT (gzip);
@@ -170,8 +171,8 @@ cherokee_encoder_gzip_init (cherokee_encoder_gzip_t *encoder)
 				 Z_DEFAULT_STRATEGY);
 
 	if (err != Z_OK) {
-		PRINT_ERROR("Error in deflateInit2() = %s\n", 
-			    get_gzip_error_string(err));
+		LOG_ERROR("Error in deflateInit2() = %s\n", 
+			  get_gzip_error_string(err));
 
 		return ret_error;
 	}
@@ -250,17 +251,16 @@ do_encode (cherokee_encoder_gzip_t *encoder,
 		case Z_STREAM_END:
 			err = zlib_deflateEnd (z);
 			if (err != Z_OK) {
-				PRINT_ERROR("Error in deflateEnd(): err=%s\n", 
-					    get_gzip_error_string(err));
+				LOG_ERROR("deflateEnd(): err=%s\n", 
+					  get_gzip_error_string(err));
 				return ret_error;
 			}
 
 			cherokee_buffer_add (out, buf, sizeof(buf) - z->avail_out);			
 			break;
 		default:
-			PRINT_ERROR("Error in deflate(): err='%s' avail=%d\n", 
-				    get_gzip_error_string(err), 
-				    z->avail_in);
+			LOG_ERROR("deflate(): err='%s' avail=%d\n", 
+				  get_gzip_error_string(err), z->avail_in);
 			
 			zlib_deflateEnd (z);
 			return ret_error;		
