@@ -110,7 +110,7 @@ _add (cherokee_fdpoll_epoll_t *fdp, int fd, int rw)
 
 	if (epoll_ctl (fdp->ep_fd, EPOLL_CTL_ADD, fd, &ev) < 0) {
 		LOG_ERRNO (errno, cherokee_err_error,
-			   "epoll_ctl(%d, EPOLL_CTL_ADD, %d): '${errno}'", fdp->ep_fd, fd);
+			   "epoll_ctl(%d, EPOLL_CTL_ADD, %d): '${errno}'\n", fdp->ep_fd, fd);
 		return ret_error;
 	}
 
@@ -137,7 +137,7 @@ _del (cherokee_fdpoll_epoll_t *fdp, int fd)
 
 	if (epoll_ctl(fdp->ep_fd, EPOLL_CTL_DEL, fd, &ev) < 0) {
 		LOG_ERRNO (errno, cherokee_err_error,
-			   "epoll_ctl(%d, EPOLL_CTL_DEL, %d): '${errno}'", fdp->ep_fd, fd);
+			   "epoll_ctl(%d, EPOLL_CTL_DEL, %d): '${errno}'\n", fdp->ep_fd, fd);
 		return ret_error;
 	}
 
@@ -228,7 +228,7 @@ _set_mode (cherokee_fdpoll_epoll_t *fdp, int fd, int rw)
 
 	if (epoll_ctl(fdp->ep_fd, EPOLL_CTL_MOD, fd, &ev) < 0) {
 		LOG_ERRNO (errno, cherokee_err_error,
-			   "epoll_ctl(%d, EPOLL_CTL_MOD, %d): '${errno}'", fdp->ep_fd, fd);
+			   "epoll_ctl(%d, EPOLL_CTL_MOD, %d): '${errno}'\n", fdp->ep_fd, fd);
 		return ret_error;
 	}
 	return ret_ok;
@@ -313,7 +313,7 @@ fdpoll_epoll_new (cherokee_fdpoll_t **fdp, int sys_fd_limit, int fd_limit)
 		 */
 #if 0
 		LOG_ERRNO (errno, cherokee_err_error,
-			   "epoll_create(%d): '${errno}'", nfd->nfiles+1);
+			   "epoll_create(%d): '${errno}'\n", nfd->nfiles+1);
 #endif
 		_free (n);
 		return ret_error;
