@@ -163,6 +163,7 @@ cherokee_http_code_to_string (cherokee_http_t code, const char **str)
 	case http_moved_temporarily:        *str = http_moved_temporarily_string; break;
 	case http_see_other:                *str = http_see_other_string; break;
 	case http_not_modified:             *str = http_not_modified_string; break;
+	case http_temporary_redirect:       *str = http_temporary_redirect_string; break;
 
 	/* 4xx
 	 */
@@ -227,6 +228,7 @@ cherokee_http_code_copy (cherokee_http_t code, cherokee_buffer_t *buf)
 		entry_code (moved_temporarily);
 		entry_code (see_other);
 		entry_code (not_modified);
+		entry_code (temporary_redirect);
 
 		/* 4xx
 		 */
