@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2008 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2009 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -18,9 +18,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
- */
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
+ */ 
 
 #if !defined (CHEROKEE_INSIDE_CHEROKEE_H) && !defined (CHEROKEE_COMPILATION)
 # error "Only <cherokee/cherokee.h> can be included directly, this file may disappear or change contents."
@@ -30,6 +30,7 @@
 #define CHEROKEE_INIT_H
 
 #include <cherokee/common.h>
+#include <cherokee/buffer.h>
 
 CHEROKEE_BEGIN_DECLS
 
@@ -40,9 +41,10 @@ ret_t cherokee_mrproper (void);
 
 /* Globals
  */
-extern cuint_t cherokee_cacheline_size;
-extern cint_t  cherokee_cpu_number;
-extern cuint_t cherokee_fdlimit;
+extern cuint_t           cherokee_cacheline_size;
+extern cint_t            cherokee_cpu_number;
+extern cuint_t           cherokee_fdlimit;
+extern cherokee_buffer_t cherokee_tmp_dir;
 
 CHEROKEE_END_DECLS
 
