@@ -30,23 +30,33 @@
 
 CHEROKEE_BEGIN_DECLS
 
+typedef enum {
+	spawn_unknown,
+	spawn_shm,
+	spawn_local
+} cherokee_source_interpreter_spawn_t;
+
 typedef struct {
-	cherokee_source_t   source;
+	cherokee_source_t    source;
+	cherokee_buffer_t    interpreter;
 
-	cherokee_buffer_t   interpreter;
-	char              **custom_env;
-	cuint_t             custom_env_len;
-	cuint_t             timeout;
+	cherokee_boolean_t   env_inherited;
+	char               **custom_env;
+	cuint_t              custom_env_len;
 
-	cherokee_boolean_t  debug;
-	pid_t               pid;
+	cuint_t              timeout;
+	cherokee_boolean_t   debug;
+	pid_t                pid;
+	time_t               last_connect;
+	time_t               spawning_since;
 
-	cherokee_buffer_t   change_user_name;
-	uid_t               change_user;
-	gid_t               change_group;
+	cherokee_buffer_t    change_user_name;
+	uid_t                change_user;
+	gid_t                change_group;
 
-	CHEROKEE_MUTEX_T   (launching_mutex);
-	cherokee_boolean_t  launching;
+	CHEROKEE_MUTEX_T                    (launching_mutex);
+	cherokee_boolean_t                   launching;
+	cherokee_source_interpreter_spawn_t  spawn_type;
 } cherokee_source_interpreter_t;
 
 #define SOURCE_INT(s)  ((cherokee_source_interpreter_t *)(s))
@@ -61,8 +71,7 @@ ret_t cherokee_source_interpreter_spawn     (cherokee_source_interpreter_t *src,
 
 ret_t cherokee_source_interpreter_connect_polling (cherokee_source_interpreter_t *src, 
 						   cherokee_socket_t             *socket,
-						   cherokee_connection_t         *conn,
-						   time_t                        *spawned);
+						   cherokee_connection_t         *conn);
 
 CHEROKEE_END_DECLS
 
